import { IDomEditor, SlateTransforms } from '@wangeditor/editor'
import { editorRef, showLoading, treeData, treeRef, treeSelectedKeys, xmlContent, xmlDOM } from '../constants'
import { TreeOption } from 'naive-ui'
import { nodeSet } from '../constants/nodeParsed'

export const handleEditor = (editor: IDomEditor) => {
    if (editor.getHtml() == '<p><br></p>') return
    console.log(editor.getHtml())
    const xmlProcessing = useXMLProcessing()
    const res = xmlProcessing.processXML(editor.getHtml(), nodeSet)
    treeData.value = res.treeData
    xmlDOM.value = res.xmlDOM
    xmlContent.value = res.xmlContent
}

export const handleClick = (key: string) => {
    treeRef.value?.scrollTo({ key })
    treeSelectedKeys.value = [key]
}

export const handleContextSelect = (key: string) => {
    if (key == 'TaskTitle') {
        const node = { type: 'TaskTitle', dataKey: 'fasdfasdf', children: [{ text: 'TaskTitle' }] }
        editorRef.value?.editorRef?.insertNode(node)
    } else if (key == 'TopicTitle') {
        const node = { type: 'TopicTitle', children: [{ text: 'TopicTitle' }] }
        editorRef.value?.editorRef?.insertNode(node)
    }
}

let lastFocusedId = ''
export const nodeProps = ({ option }: { option: TreeOption }) => {
    return {
        onClick() {
            const container = editorRef.value?.editorRef.getEditableContainer()
            const id = container.querySelector(`[data-key="${option.key}"]`)?.getAttribute('id')
            editorRef.value?.editorRef.scrollToElem([id])
            if (container) {
                if (lastFocusedId) {
                    container.querySelector(`#${lastFocusedId}`)?.classList.remove('focus')
                }
                lastFocusedId = option.key as string
                container.querySelector(`#${lastFocusedId}`)?.classList.add('focus')
            }
        }
    }
}
export const uploadXml = async () => {
    const input = document.createElement('input')
    input.type = 'file'
    input.accept = 'application/xml,text/xml'
    input.multiple = false
    input.click()
    input.addEventListener('change', async (event: Event) => {
        const files = (event.target as HTMLInputElement).files
        if (files && files.length > 0) {
            const file = files[0]
            const xmlProcessing = useXMLProcessing()
            showLoading.value = true
            const res = await xmlProcessing.processFile(file, nodeSet)
            showLoading.value = false
            treeData.value = res.treeData
            xmlDOM.value = res.xmlDOM
            xmlContent.value = res.xmlContent
            editorRef.value?.editorRef?.setHtml(xmlContent.value)
        }
    })
}
